@@ -1,4 +1,4 @@
-#  Copyright (c) 2020. Lena "Teekeks" During <info@teawork.de>
+#  Copyright (c) 2021. Lena "Teekeks" During <info@teawork.de>
 """
 Full Implementation of the Twitch EventSub
 ------------------------------------------
@@ -61,8 +61,10 @@ Short code example:
     print('subscribing to hooks:')
     hook.listen_channel_follow(user_id, on_follow)
 
-    input('press Enter to shut down...')
-    hook.stop()
+    try:
+        input('press Enter to shut down...')
+    finally:
+        hook.stop()
     print('done')
 
 ********************
@@ -101,7 +103,7 @@ class EventSub:
     :param ~twitchAPI.twitch.Twitch twitch:  a app authenticated instance of :code:`Twitch`
     :var str secret: A random secret string. Set this for added security.
     :var str callback_url: The full URL of the webhook.
-    :var bool wait_for_subscription_confirm: Set this to false if you dont want to wait for a subscription confirm.
+    :var bool wait_for_subscription_confirm: Set this to false if you don't want to wait for a subscription confirm.
                     |default| :code:`True`
     :var int wait_for_subscription_confirm_timeout: Max time in seconds to wait for a subscription confirmation.
                     Only used if ``wait_for_subscription_confirm`` is set to True. |default| :code:`30`
@@ -175,9 +177,9 @@ class EventSub:
         self.__hook_thread.start()
 
     def stop(self):
-        """Stops the Webhook
+        """Stops the EventSub client
 
-        Please make sure to unsubscribe from all subscriptions!
+        This also unsubscribes from all known subscriptions if unsubscribe_on_stop is True
 
         :rtype: None
         """
@@ -250,6 +252,7 @@ class EventSub:
                 if self.__callbacks[sub_id]['active']:
                     return sub_id
                 asyncio.get_event_loop().run_until_complete(asyncio.sleep(0.01))
+            self.__callbacks.pop(sub_id, None)
             raise EventSubSubscriptionTimeout()
         return sub_id
 
@@ -308,6 +311,7 @@ class EventSub:
             succ = self.__twitch.delete_eventsub_subscription(_id)
             if not succ:
                 self.__logger.warning(f'failed to unsubscribe from event {_id}')
+        self.__callbacks.clear()
 
     def unsubscribe_all_known(self):
         """Unsubscribe from all subscriptions known to this client."""
@@ -316,12 +320,14 @@ class EventSub:
             succ = self.__twitch.delete_eventsub_subscription(key)
             if not succ:
                 self.__logger.warning(f'failed to unsubscribe from event {key}')
+        self.__callbacks.clear()
 
     def unsubscribe_topic(self, topic_id: str) -> bool:
-        """Unsubscribe from a specific topic.
-
-        This is a shorthand for ~twitchAPI.twitch.Twitch.delete_eventsub_subscription"""
-        return self.__twitch.delete_eventsub_subscription(topic_id)
+        """Unsubscribe from a specific topic."""
+        result = self.__twitch.delete_eventsub_subscription(topic_id)
+        if result:
+            self.__callbacks.pop(topic_id, None)
+        return result
 
     def listen_channel_update(self, broadcaster_user_id: str, callback: CALLBACK_TYPE) -> str:
         """A broadcaster updates their channel properties e.g., category, title, mature flag, broadcast, or language.
